@@ -1,7 +1,5 @@
 from dateutil.parser import parse as dateutil_parse
 
-from dgp_server.log import logger
-
 from dataflows import Flow, concatenate, add_computed_field, \
     unpivot, set_primary_key, PackageWrapper, set_type, validate
 from dataflows.base.schema_validator import ignore
@@ -135,7 +133,6 @@ class TransformDGP(BaseDataGenusProcessor):
 
         def func(package: PackageWrapper):
             parsers = []
-            logger.error('DESCRIPTOR NOW %r', package.pkg.descriptor)
             for resource in package.pkg.descriptor['resources']:
                 if resource['name'] != RESOURCE_NAME:
                     continue
